@@ -73,6 +73,21 @@ inline void deviatoric(const T& A, R& ret);
 template <class T>
 inline auto Deviatoric(const T& A);
 
+// Symmetric part of a tensor (== A - Hydrostatic(A) * I2)
+// "ret" may be the same as "A"
+template <class T, class R>
+inline void sym(const T& A, R& ret);
+
+template <class T>
+inline auto Sym(const T& A);
+
+// A . B
+template <class T, class R>
+inline void A2_dot_B2(const T& A, const T& B, R& ret);
+
+template <class T>
+inline auto A2_dot_B2(const T& A, const T& B);
+
 // A * B
 template <class T, class R>
 inline void A2_dyadic_B2(const T& A, const T& B, R& ret);
@@ -162,25 +177,30 @@ namespace pointer {
 
     // Trace of second order tensor
     template <class T>
-    inline T trace(const T* A);
+    inline T Trace(const T* A);
 
     // trace(A) / 2
     template <class T>
-    inline T hydrostatic(const T* A);
+    inline T Hydrostatic(const T* A);
+
+    // Symmetrise tensor
+    // "ret" may be the same as "A"
+    template <class T>
+    inline void sym(const T* A, T* ret);
 
     // Deviatoric decomposition of second order tensor
     // Returns hydrostatic part
     // "ret" may be the same as "A"
     template <class T>
-    inline T hydrostatic_deviatoric(const T* A, T* ret);
+    inline T Hydrostatic_deviatoric(const T* A, T* ret);
 
     // dev(A) : dev(A)
     template <class T>
-    inline T deviatoric_ddot_deviatoric(const T* A);
+    inline T Deviatoric_ddot_deviatoric(const T* A);
 
     // sqrt(dev(A) : dev(A))
     template <class T>
-    inline T norm_deviatoric(const T* A);
+    inline T Norm_deviatoric(const T* A);
 
     // A : B
     template <class T>
@@ -195,6 +215,10 @@ namespace pointer {
     template <class T>
     inline void A2_dyadic_B2(const T* A, const T* B, T* ret);
 
+    // A . B
+    template <class T>
+    inline void A2_dot_B2(const T* A, const T* B, T* ret);
+
     // A : B
     template <class T>
     inline void A4_ddot_B2(const T* A, const T* B, T* ret);
