@@ -80,6 +80,14 @@ inline void deviatoric(const T& A, R& ret);
 template <class T>
 inline auto Deviatoric(const T& A);
 
+// Symmetric part of a tensor (== A - Hydrostatic(A) * I2)
+// "ret" may be the same as "A"
+template <class T, class R>
+inline void sym(const T& A, R& ret);
+
+template <class T>
+inline auto Sym(const T& A);
+
 // inv(A)
 template <class T, class R>
 inline void inv(const T& A, R& ret);
@@ -104,10 +112,10 @@ inline auto A2_dot_A2T(const T& A);
 
 // A . B
 template <class T, class R>
-inline void A2_dot_B2(const T& A, R& ret);
+inline void A2_dot_B2(const T& A, const T& B, R& ret);
 
 template <class T>
-inline auto A2_dot_B2(const T& A);
+inline auto A2_dot_B2(const T& A, const T& B);
 
 // A * B
 template <class T, class R>
@@ -205,34 +213,39 @@ namespace pointer {
 
     // Trace of second order tensor
     template <class T>
-    inline T trace(const T* A);
+    inline T Trace(const T* A);
 
     // trace(A) / 3
     template <class T>
-    inline T hydrostatic(const T* A);
+    inline T Hydrostatic(const T* A);
 
     // Determinant
     template <class T>
-    inline T det(const T* A);
+    inline T Det(const T* A);
+
+    // Symmetrise tensor
+    // "ret" may be the same as "A"
+    template <class T>
+    inline void sym(const T* A, T* ret);
 
     // inv(A)
     // Returns determinant
     template <class T>
-    inline T inv(const T* A, T* ret);
+    inline T Inv(const T* A, T* ret);
 
     // Deviatoric decomposition of second order tensor
     // Returns hydrostatic part
     // "ret" may be the same as "A"
     template <class T>
-    inline T hydrostatic_deviatoric(const T* A, T* ret);
+    inline T Hydrostatic_deviatoric(const T* A, T* ret);
 
     // dev(A) : dev(A)
     template <class T>
-    inline T deviatoric_ddot_deviatoric(const T* A);
+    inline T Deviatoric_ddot_deviatoric(const T* A);
 
     // sqrt(dev(A) : dev(A))
     template <class T>
-    inline T norm_deviatoric(const T* A);
+    inline T Norm_deviatoric(const T* A);
 
     // A : B
     template <class T>
